summaryrefslogtreecommitdiff
path: root/sys/arch/sgi
diff options
context:
space:
mode:
authorMiod Vallat <miod@cvs.openbsd.org>2009-11-19 20:16:28 +0000
committerMiod Vallat <miod@cvs.openbsd.org>2009-11-19 20:16:28 +0000
commit06f6bd12768d8c5694d2d4f8e99ea74ddc0c60d0 (patch)
tree400c4fccdf8c7b765c899a68edfb3d9b37c8b2db /sys/arch/sgi
parentbfb1e5309562c6883170e2748c69777bed55600f (diff)
Rename KSEG* defines to CKSEG* to match their names in 64 bit mode; also
define more 64 bit spaces.
Diffstat (limited to 'sys/arch/sgi')
-rw-r--r--sys/arch/sgi/sgi/genassym.cf4
-rw-r--r--sys/arch/sgi/sgi/ip32_machdep.c4
-rw-r--r--sys/arch/sgi/sgi/machdep.c8
3 files changed, 9 insertions, 7 deletions
diff --git a/sys/arch/sgi/sgi/genassym.cf b/sys/arch/sgi/sgi/genassym.cf
index 5833c78c70b..36771d7c63e 100644
--- a/sys/arch/sgi/sgi/genassym.cf
+++ b/sys/arch/sgi/sgi/genassym.cf
@@ -1,4 +1,4 @@
-# $OpenBSD: genassym.cf,v 1.17 2009/10/22 22:08:54 miod Exp $
+# $OpenBSD: genassym.cf,v 1.18 2009/11/19 20:16:27 miod Exp $
#
# Copyright (c) 1997 Per Fogelstrom / Opsycon AB
#
@@ -60,6 +60,8 @@ member ci_curproc
member ci_curprocpaddr
member ci_ipl
+export CKSEG0_BASE
+export CKSEG1_BASE
export VM_MIN_KERNEL_ADDRESS
export SIGFPE
diff --git a/sys/arch/sgi/sgi/ip32_machdep.c b/sys/arch/sgi/sgi/ip32_machdep.c
index 492828ef108..a5d6e10e228 100644
--- a/sys/arch/sgi/sgi/ip32_machdep.c
+++ b/sys/arch/sgi/sgi/ip32_machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ip32_machdep.c,v 1.11 2009/11/19 06:06:51 miod Exp $ */
+/* $OpenBSD: ip32_machdep.c,v 1.12 2009/11/19 20:16:27 miod Exp $ */
/*
* Copyright (c) 2003-2004 Opsycon AB (www.opsycon.se / www.opsycon.com)
@@ -67,7 +67,7 @@ crime_configure_memory(void)
#endif
bank_ctrl =
- (void *)PHYS_TO_KSEG1(CRIMEBUS_BASE + CRIME_MEM_BANK0_CONTROL);
+ (void *)PHYS_TO_CKSEG1(CRIMEBUS_BASE + CRIME_MEM_BANK0_CONTROL);
for (bank = 0; bank < CRIME_MAX_BANKS; bank++) {
ctrl = bank_ctrl[bank];
addr = (ctrl & CRIME_MEM_BANK_ADDR) << 25;
diff --git a/sys/arch/sgi/sgi/machdep.c b/sys/arch/sgi/sgi/machdep.c
index 20d9719953b..bbe75a18722 100644
--- a/sys/arch/sgi/sgi/machdep.c
+++ b/sys/arch/sgi/sgi/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.89 2009/11/19 20:13:54 miod Exp $ */
+/* $OpenBSD: machdep.c,v 1.90 2009/11/19 20:16:27 miod Exp $ */
/*
* Copyright (c) 2003-2004 Opsycon AB (www.opsycon.se / www.opsycon.com)
@@ -158,7 +158,7 @@ mips_init(int argc, void *argv, caddr_t boot_esym)
#ifdef notyet
/*
* Make sure KSEG0 cacheability match what we intend to use.
*
* XXX This does not work as expected on IP30. Does ARCBios
* XXX depend on this?
@@ -314,11 +314,11 @@ mips_init(int argc, void *argv, caddr_t boot_esym)
if (IS_XKPHYS((vaddr_t)start))
firstkernpa = XKPHYS_TO_PHYS((vaddr_t)start);
else
- firstkernpa = KSEG0_TO_PHYS((vaddr_t)start);
+ firstkernpa = CKSEG0_TO_PHYS((vaddr_t)start);
if (IS_XKPHYS((vaddr_t)ekern))
lastkernpa = XKPHYS_TO_PHYS((vaddr_t)ekern);
else
- lastkernpa = KSEG0_TO_PHYS((vaddr_t)ekern);
+ lastkernpa = CKSEG0_TO_PHYS((vaddr_t)ekern);
firstkernpage = atop(trunc_page(firstkernpa));
lastkernpage = atop(round_page(lastkernpa));
@@ -158,7 +158,7 @@ mips_init(int argc, void *argv, caddr_t boot_esym)
#ifdef notyet
/*
- * Make sure KSEG0 cacheability match what we intend to use.
+ * Make sure CKSEG0 cacheability match what we intend to use.
*
* XXX This does not work as expected on IP30. Does ARCBios